'use strict';

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _utils = require('./utils');

var _maven = require('./maven.manager');

var _npm = require('./npm.manager');

var _schema = require('./schema.manager');

var _storage = require('./storage.manager');

var _validator = require('./validator.manager');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @license
 * Copyright Opensoft. All Rights Reserved.
 *
 * Use of this source code is governed by an Apache 2 license that can be
 * found in the LICENSE file at https://bitbucket.org/opensoftgitrepo/lightweightform/src/develop/LICENSE
 */
var root = process.cwd();


module.exports = {
  generate: function generate(schemaFilePath, outputDir, projectName, options) {
    var schemaJson = null;
    if (_path2.default.isAbsolute(schemaFilePath)) {
      schemaJson = require(schemaFilePath);
    } else {
      schemaJson = require(root + '/' + schemaFilePath);
    }

    var outputModuleDirectory = null;
    var projectBaseDirectory = '/';
    if (_path2.default.isAbsolute(outputDir)) {
      outputModuleDirectory = '' + outputDir + projectBaseDirectory;
    } else {
      outputModuleDirectory = root + '/' + outputDir + projectBaseDirectory;
    }

    options.groupid += '.kotlin';

    var commonDirectory = outputModuleDirectory + '/' + projectName + '-common';
    var commonJsDirectory = commonDirectory + '-js';
    var commonJvmDirectory = commonDirectory + '-jvm';
    if (!options.skipModules) {
      (0, _utils.createDirectory)(outputModuleDirectory);
      (0, _maven.createMavenProject)(outputModuleDirectory, commonDirectory, commonJsDirectory, commonJvmDirectory, projectName, options);
      (0, _npm.createCommonJsPackageJson)(outputModuleDirectory, projectName);
    }

    var commonModuleBaseDirectory = '' + outputModuleDirectory;
    if (!options.skipModules) {
      commonModuleBaseDirectory = commonDirectory + '/src/main/kotlin/';
    }
    (0, _schema.processSchema)(commonModuleBaseDirectory, options, schemaJson);
    (0, _storage.processStorage)(commonModuleBaseDirectory, options, schemaJson);
    if (!options.skipValidationMessages) {
      (0, _validator.processValidator)(commonModuleBaseDirectory, options);
    }
  }
};